- README.md
- LICENSE.txt
- NOTICE.txt

- API Reference / Documentation
  - docs.html (online copy)
  - docs.html (local copy)

- Article with overview of functionality in Armadillo
  - armadillo_joss_2016.pdf (online copy)
  - armadillo_joss_2016.pdf (local copy)

- Paper with overview of sparse matrix functionality in Armadillo
  - armadillo_lncs_2018.pdf (online copy)
  - armadillo_lncs_2018.pdf (local copy)

- Paper with details on Gaussian Mixture Models in Armadillo:
  - armadillo_spcs_2017.pdf (online copy)
  - armadillo_spcs_2017.pdf (local copy)

- Overview technical report (old)
  - armadillo_nicta_2010.pdf (online copy)
  - armadillo_nicta_2010.pdf (local copy)

- Article on integration of Armadillo with R:
  - rcpp_armadillo_csda_2014.pdf (online copy)
  - rcpp_armadillo_csda_2014.pdf (local copy)